==> haskell-strict-0.3.2-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-strict.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: strict
version: 0.3.2
id: strict-0.3.2-GUMMwuTAWLDDoRWXG04D6Z
key: strict-0.3.2-GUMMwuTAWLDDoRWXG04D6Z
license: BSD-3-Clause
copyright: (c) 2006-2007 by Roman Leshchinskiy
maintainer: Don Stewart <dons@galois.com>
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage: http://www.cse.unsw.edu.au/~rl/code/strict.html
synopsis: Strict data types and String IO.
description:
    This package provides strict versions of some standard Haskell data
    types (pairs, Maybe and Either). It also contains strict IO
    operations.
category: Data, System
abi: bb84743753e36e5d9eb9840a6b2de2dc
exposed: True
exposed-modules:
    Data.Strict Data.Strict.Either Data.Strict.Maybe Data.Strict.Tuple
    System.IO.Strict
import-dirs: /usr/lib/ghc-8.4.3/site-local/strict-0.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/strict-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/strict-0.3.2
hs-libraries: HSstrict-0.3.2-GUMMwuTAWLDDoRWXG04D6Z
depends:
    array-0.5.2.0 base-4.11.1.0
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-strict/html/strict.haddock
haddock-html: /usr/share/doc/haskell-strict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-strict-0.3.2-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-strict.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: strict
version: 0.3.2
id: strict-0.3.2-Bz4DFS53pbt7YgwTKjzDci
key: strict-0.3.2-Bz4DFS53pbt7YgwTKjzDci
license: BSD-3-Clause
copyright: (c) 2006-2007 by Roman Leshchinskiy
maintainer: Don Stewart <dons@galois.com>
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage: http://www.cse.unsw.edu.au/~rl/code/strict.html
synopsis: Strict data types and String IO.
description:
    This package provides strict versions of some standard Haskell data
    types (pairs, Maybe and Either). It also contains strict IO
    operations.
category: Data, System
abi: add5a2add40bc27ab4e617834539855c
exposed: True
exposed-modules:
    Data.Strict Data.Strict.Either Data.Strict.Maybe Data.Strict.Tuple
    System.IO.Strict
import-dirs: /usr/lib/ghc-8.6.1/site-local/strict-0.3.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/strict-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/strict-0.3.2
hs-libraries: HSstrict-0.3.2-Bz4DFS53pbt7YgwTKjzDci
depends:
    array-0.5.2.0 base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-strict/html/strict.haddock
haddock-html: /usr/share/doc/haskell-strict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
